package javax.swing.plaf.multi;

import javax.swing.UIManager;
import javax.swing.JComponent;
import java.util.Vector;
import javax.swing.plaf.ComponentUI;
import javax.swing.UIDefaults;
import javax.swing.LookAndFeel;

public class MultiLookAndFeel extends LookAndFeel
{
    public MultiLookAndFeel() {
    }
    
    @Override
    public String getName() {
        return "Multiplexing Look and Feel";
    }
    
    @Override
    public String getID() {
        return "Multiplex";
    }
    
    @Override
    public String getDescription() {
        return "Allows multiple UI instances per component instance";
    }
    
    @Override
    public boolean isNativeLookAndFeel() {
        return false;
    }
    
    @Override
    public boolean isSupportedLookAndFeel() {
        return true;
    }
    
    @Override
    public UIDefaults getDefaults() {
        String str = "javax.swing.plaf.multi.Multi";
        Object[] keyValueList = { "ButtonUI", str + "ButtonUI", "CheckBoxMenuItemUI", str + "MenuItemUI", "CheckBoxUI", str + "ButtonUI", "ColorChooserUI", str + "ColorChooserUI", "ComboBoxUI", str + "ComboBoxUI", "DesktopIconUI", str + "DesktopIconUI", "DesktopPaneUI", str + "DesktopPaneUI", "EditorPaneUI", str + "TextUI", "FileChooserUI", str + "FileChooserUI", "FormattedTextFieldUI", str + "TextUI", "InternalFrameUI", str + "InternalFrameUI", "LabelUI", str + "LabelUI", "ListUI", str + "ListUI", "MenuBarUI", str + "MenuBarUI", "MenuItemUI", str + "MenuItemUI", "MenuUI", str + "MenuItemUI", "OptionPaneUI", str + "OptionPaneUI", "PanelUI", str + "PanelUI", "PasswordFieldUI", str + "TextUI", "PopupMenuSeparatorUI", str + "SeparatorUI", "PopupMenuUI", str + "PopupMenuUI", "ProgressBarUI", str + "ProgressBarUI", "RadioButtonMenuItemUI", str + "MenuItemUI", "RadioButtonUI", str + "ButtonUI", "RootPaneUI", str + "RootPaneUI", "ScrollBarUI", str + "ScrollBarUI", "ScrollPaneUI", str + "ScrollPaneUI", "SeparatorUI", str + "SeparatorUI", "SliderUI", str + "SliderUI", "SpinnerUI", str + "SpinnerUI", "SplitPaneUI", str + "SplitPaneUI", "TabbedPaneUI", str + "TabbedPaneUI", "TableHeaderUI", str + "TableHeaderUI", "TableUI", str + "TableUI", "TextAreaUI", str + "TextUI", "TextFieldUI", str + "TextUI", "TextPaneUI", str + "TextUI", "ToggleButtonUI", str + "ButtonUI", "ToolBarSeparatorUI", str + "SeparatorUI", "ToolBarUI", str + "ToolBarUI", "ToolTipUI", str + "ToolTipUI", "TreeUI", str + "TreeUI", "ViewportUI", str + "ViewportUI" };
        MultiUIDefaults multiUIDefaults = new MultiUIDefaults(keyValueList.length / 2, 0.75f);
        multiUIDefaults.putDefaults(keyValueList);
        return multiUIDefaults;
    }
    
    public static ComponentUI createUIs(ComponentUI componentUI, Vector vector, JComponent component) {
        ComponentUI ui = UIManager.getDefaults().getUI(component);
        if (ui != null) {
            vector.addElement(ui);
            LookAndFeel[] auxiliaryLookAndFeels = UIManager.getAuxiliaryLookAndFeels();
            if (auxiliaryLookAndFeels != null) {
                for (int i = 0; i < auxiliaryLookAndFeels.length; ++i) {
                    ComponentUI ui2 = auxiliaryLookAndFeels[i].getDefaults().getUI(component);
                    if (ui2 != null) {
                        vector.addElement(ui2);
                    }
                }
            }
            if (vector.size() == 1) {
                return (ComponentUI)vector.elementAt(0);
            }
            return componentUI;
        }
        else {
            return null;
        }
    }
    
    protected static ComponentUI[] uisToArray(Vector vector) {
        if (vector == null) {
            return new ComponentUI[0];
        }
        int size = vector.size();
        if (size > 0) {
            ComponentUI[] array = new ComponentUI[size];
            for (int i = 0; i < size; ++i) {
                array[i] = (ComponentUI)vector.elementAt(i);
            }
            return array;
        }
        return null;
    }
}
